==> ESCAPE-0.9.2-2768-cp38-cp38-linux_x86_64.whl: escape/utils/widgets/model.py <==
import numpy as np

from escape.utils.widgets.base import PlotObjectLayout
from escape.utils.widgets.plot import ModelPlot2dWidget, ModelMapWidget
from escape.utils.widgets.plot import PLOT_TYPE_KW,\
    PLOT2D_TYPE, MAP_TYPE, PLOT_TYPES


class ModelObjectLayout(PlotObjectLayout):
    
    plot2d_widget_class = ModelPlot2dWidget
    map_widget_class = ModelMapWidget
    
    
    def _update(self, buf=False):
        escobj = self.escobj
        dims = escobj.dimensions
        
        dobj = escobj.data
        xarr = np.asarray(dobj.ini_coordinates)
        yarr = np.asarray(dobj.ini_intensities)
        earr = np.asarray(dobj.ini_errors)
        if not len(earr):
            earr = np.sqrt(yarr)
        marr = np.asarray(dobj.mask)
        if not buf:
            escobj()
        sarr = np.asarray(escobj.simulation)
        rarr = np.asarray(escobj.residuals)
        
        if dims == 1:
            self.center.update(
                np.ma.masked_array(xarr, ~marr),
                np.ma.masked_array(yarr, ~marr),
                np.ma.masked_array(earr, ~marr),
                np.ma.masked_array(sarr, ~marr),
                np.ma.masked_array(rarr, ~marr),
                model_legend=escobj.name,
                data_legend=dobj.name)
        else:
            plot_type=self._plot_type
            coordidx = self._coordidx
            if plot_type==PLOT2D_TYPE:
                if not isinstance(coordidx, int):
                    raise TypeError("Unexpected type of coordinate index, expected int, got {0}".format(
                        type(coordidx)
                    ))
                xarr=xarr[coordidx::dims]
                self.center.update(
                    np.ma.masked_array(xarr, ~marr),
                    np.ma.masked_array(yarr, ~marr),
                    np.ma.masked_array(earr, ~marr),
                    np.ma.masked_array(sarr, ~marr),
                    np.ma.masked_array(rarr, ~marr),
                    model_legend=escobj.name,
                    data_legend=dobj.name)
            elif plot_type==MAP_TYPE:
                if dims>2:
                    if not isinstance(coordidx, (list, tuple)):
                        raise TypeError("Unexpected type of coordinate index, expected list or tuple, got {0}".format(
                            type(coordidx)
                        ))
                    
                    msk = np.zeros(shape=xarr.shape, dtype=bool)
                    
                    for idx in coordidx:
                        msk[idx::dims] = True
                    xarr = xarr[msk]
                rows = self._rows
                cols = int(len(yarr)/rows)
                if rows*cols!=len(yarr):
                    raise ValueError("Cannot build map with given number of rows")
                yarr = yarr.reshape((rows, cols))
                sarr = sarr.reshape((rows, cols))
                rarr = rarr.reshape((rows, cols))
                marr = marr.reshape((rows, cols))
                xarr = xarr.reshape((int(len(xarr) / 2), 2))
                xmin, xmax = np.min(xarr[:, 0]), np.max(xarr[:, 0])
                ymin, ymax = np.min(xarr[:, 1]), np.max(xarr[:, 1])
                self.center.update(np.ma.masked_array(yarr, ~marr),
                                   np.ma.masked_array(sarr, ~marr),
                                   np.ma.masked_array(rarr, ~marr),
                                   extent=(xmin, xmax, ymin, ymax))
            else:
                raise ValueError("Wrong type of plot, expected one of [{0}], got {1}".format(
                    ", ".join(PLOT_TYPES), plot_type
                ))            
    
    def update(self, *args):
        if self._no_update:
            return
        self._update(False)

==> ESCAPE-0.9.7-3760-cp38-cp38-linux_x86_64.whl: escape/utils/widgets/model.py <==
import numpy as np

from escape.utils.widgets.base import PlotObjectLayout
from escape.utils.widgets.plot import ModelPlot2dWidget, ModelMapWidget
from escape.utils.widgets.plot import PLOT_TYPE_KW, \
    PLOT2D_TYPE, MAP_TYPE, PLOT_TYPES


class ModelObjectLayout(PlotObjectLayout):
    
    plot2d_widget_class = ModelPlot2dWidget
    map_widget_class = ModelMapWidget
    
    def _update(self, buf=False):
        escobj = self.escobj
        dims = escobj.domain_size
        
        dobj = escobj.data
        xarr = np.array(dobj.ini_coordinates)
        yarr = np.array(dobj.ini_intensities)
        earr = np.array(dobj.ini_errors)
        if not len(earr):
            earr = np.sqrt(yarr)
        marr = np.array(dobj.mask)
        if not buf:
            escobj()
        sarr = np.array(escobj.simulation)
        rarr = np.array(escobj.residuals)
        
        if dims == 1:
            self.center.update(
                np.ma.masked_array(xarr, ~marr),
                np.ma.masked_array(yarr, ~marr),
                np.ma.masked_array(earr, ~marr),
                np.ma.masked_array(sarr, ~marr),
                np.ma.masked_array(rarr, ~marr),
                model_legend=escobj.name,
                data_legend=dobj.name)
        else:
            plot_type = self._plot_type
            coordidx = self._coordidx
            if plot_type == PLOT2D_TYPE:
                if not isinstance(coordidx, int):
                    raise TypeError("Unexpected type of coordinate index, expected int, got {0}".format(
                        type(coordidx)
                    ))
                xarr = xarr[coordidx::dims]
                self.center.update(
                    np.ma.masked_array(xarr, ~marr),
                    np.ma.masked_array(yarr, ~marr),
                    np.ma.masked_array(earr, ~marr),
                    np.ma.masked_array(sarr, ~marr),
                    np.ma.masked_array(rarr, ~marr),
                    model_legend=escobj.name,
                    data_legend=dobj.name)
            elif plot_type == MAP_TYPE:
                if dims > 2:
                    if not isinstance(coordidx, (list, tuple)):
                        raise TypeError("Unexpected type of coordinate index, expected list or tuple, got {0}".format(
                            type(coordidx)
                        ))
                    
                    msk = np.zeros(shape=xarr.shape, dtype=bool)
                    
                    for idx in coordidx:
                        msk[idx::dims] = True
                    xarr = xarr[msk]
                rows = self._rows
                cols = int(len(yarr) / rows)
                if rows * cols != len(yarr):
                    raise ValueError("Cannot build map with given number of rows")
                yarr = yarr.reshape((rows, cols))
                sarr = sarr.reshape((rows, cols))
                rarr = rarr.reshape((rows, cols))
                marr = marr.reshape((rows, cols))
                xarr = xarr.reshape((int(len(xarr) / 2), 2))
                xmin, xmax = np.min(xarr[:, 0]), np.max(xarr[:, 0])
                ymin, ymax = np.min(xarr[:, 1]), np.max(xarr[:, 1])
                self.center.update(np.ma.masked_array(yarr, ~marr),
                                   np.ma.masked_array(sarr, ~marr),
                                   np.ma.masked_array(rarr, ~marr),
                                   extent=(xmin, xmax, ymin, ymax))
            else:
                raise ValueError("Wrong type of plot, expected one of [{0}], got {1}".format(
                    ", ".join(PLOT_TYPES), plot_type
                ))            
    
    def update(self, *args):
        if self._no_update:
            return
        self._update(False)
